@@ -7,6 +7,6 @@ from snowebsvg import settings
 class Command(BaseCommand):
 
     def handle(self, *args, **options):
-        for collection_name in os.listdir(settings.BASE_DIR_COLLECTION):
+        for collection_name in os.listdir(settings.dir_collection()):
             collection, _ = Collection.objects.get_or_create(key=collection_name)
             collection.build()
